@@ -37,7 +37,12 @@ def register(target, message):
 def send(relay, target, message, template, vars):
     confirm_address = register(target, message)
     vars.update(locals())
-    msg = view.respond(template, vars)
+    msg = view.respond(vars, template, To=message['from'],
+                       From="%(confirm_address)s@%(host)s",
+                       Subject="Confirmation required")
+
+    msg['Reply-To'] = "%(confirm_address)s@%(host)s" % vars
+
     relay.deliver(msg)
 
 def clear():
