@@ -5,10 +5,11 @@ from lamson.server import Relay
 from lamson.utils import configure_database
 import jinja2
 import logging
+import logging.config
 import os
 
 # configure logging to go to a log file
-logging.basicConfig(filename=settings.log_file, level=logging.DEBUG)
+logging.config.fileConfig("config/test_logging.conf")
 
 # the relay host to actually send the final message to (set debug=1 to see what
 # the relay is saying to the log server).
@@ -21,7 +22,7 @@ settings.receiver = None
 settings.database = configure_database(settings.database_config, also_create=False)
 
 Router.defaults(**settings.router_defaults)
-Router.load(settings.handlers)
+Router.load(settings.handlers + settings.queue_handlers)
 Router.RELOAD=True
 
 view.LOADER = jinja2.Environment(
