@@ -55,31 +55,31 @@ import sys
 import inspect
 
 
-def s_ip_address(scanner, token): return ['ip_address', token]
-def s_word(scanner, token): return ['word', token]
-def s_email_addr(scanner, token): return ['email', token]
-def s_option(scanner, token): return ['option', token.split("-")[-1]]
-def s_int(scanner, token): return ['int', int(token) ]
-def s_bool(scanner, token): return ['bool', bool(token) ]
-def s_empty(scanner, token): return ['empty', '']
-def s_string(scanner, token): return ['string', token]
-def s_trailing(scanner, token): return ['trailing', None]
+S_IP_ADDRESS = lambda x, token: ['ip_address', token]
+S_WORD = lambda x, token:  ['word', token]
+S_EMAIL_ADDR = lambda x, token:  ['email', token]
+S_OPTION = lambda x, token:  ['option', token.split("-")[-1]]
+S_INT = lambda x, token:  ['int', int(token) ]
+S_BOOL = lambda x, token:  ['bool', bool(token) ]
+S_EMPTY = lambda x, token:  ['empty', '']
+S_STRING = lambda x, token:  ['string', token]
+S_TRAILING = lambda x, token:  ['trailing', None]
 
-class ArgumentError(RuntimeError): 
+class ArgumentError(Exception): 
     """Thrown when lamson.args encounters a command line format error."""
     pass
 
 
-scanner = re.Scanner([
-    (r"[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,4}", s_email_addr),
-    (r"[0-9]+\.[0-9]+\.[0-9]+\.[0-9]", s_ip_address),
-    (r"-+[a-zA-Z0-9]+", s_option),
-    (r"True", s_bool),
-    (r"[0-9]+", s_int),
-    (r"--", s_trailing),
-    (r"[a-z\-]+", s_word),
-    (r"\s", s_empty),
-    (r".+", s_string),
+SCANNER = re.Scanner([
+    (r"[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,4}", S_EMAIL_ADDR),
+    (r"[0-9]+\.[0-9]+\.[0-9]+\.[0-9]", S_IP_ADDRESS),
+    (r"-+[a-zA-Z0-9]+", S_OPTION),
+    (r"True", S_BOOL),
+    (r"[0-9]+", S_INT),
+    (r"--", S_TRAILING),
+    (r"[a-z\-]+", S_WORD),
+    (r"\s", S_EMPTY),
+    (r".+", S_STRING),
 ])
 
 
@@ -111,18 +111,18 @@ def peek(tokens, of_type):
     return tokens[0][0] == of_type
 
 
-def Trailing(data, tokens):
+def trailing_production(data, tokens):
     """Parsing production that handles trailing arguments after a -- is given."""
     data['TRAILING'] = [x[1] for x in tokens]
     del tokens[:]
 
-def Option(data, tokens):
+def option_production(data, tokens):
     """The Option production, used for -- or - options.  The number of - aren't 
     important.  It will handle either individual options, or paired options."""
     if peek(tokens, 'trailing'):
         # this means the rest are trailing arguments, collect them up
         match(tokens, 'trailing')
-        Trailing(data, tokens)
+        trailing_production(data, tokens)
     else:
         opt = match(tokens, 'option')
         if not tokens:
@@ -136,15 +136,15 @@ def Option(data, tokens):
             data[opt] = match(tokens)
 
 
-def Options(tokens):
+def options_production(tokens):
     """List of options, optionally after the command has already been taken off."""
     data = {}
     while tokens:
-        Option(data, tokens)
+        option_production(data, tokens)
     return data
 
 
-def Command(tokens):
+def command_production(tokens):
     """The command production, just pulls off a word really."""
     return match(tokens, 'word')
 
@@ -156,7 +156,7 @@ def tokenize(argv):
 
     tokens = []
     for arg in argv:
-        toks, remainder = scanner.scan(arg)
+        toks, remainder = SCANNER.scan(arg)
         if remainder or len(toks) > 1:
             tokens.append(['string', arg])
         else:
@@ -181,10 +181,10 @@ def parse(argv):
         return None, {}
     elif peek(tokens, "word"):
         # this is a command style argument
-        return Command(tokens), Options(tokens)
+        return command_production(tokens), options_production(tokens)
     else:
         # options only style
-        return None, Options(tokens)
+        return None, options_production(tokens)
 
 
 def determine_kwargs(function):
@@ -198,7 +198,7 @@ def determine_kwargs(function):
     keys = spec[0]
     values = spec[-1]
     result = {}
-    for i in range(0,len(keys)):
+    for i in range(0, len(keys)):
         result[keys[i]] = values[i]
     return result
 
@@ -235,13 +235,13 @@ def command_module(mod, command, options, ending="_command"):
 def available_help(mod, ending="_command"):
     """Returns the dochelp from all functions in this module that have _command
     at the end."""
-    help = []
+    help_text = []
     for key in mod.__dict__:
         if key.endswith(ending):
             name = key.split(ending)[0]
-            help.append(name + ":\n" + mod.__dict__[key].__doc__)
+            help_text.append(name + ":\n" + mod.__dict__[key].__doc__)
 
-    return help
+    return help_text
 
 
 def help_for_command(mod, command, ending="_command"):
