@@ -35,6 +35,7 @@ import signal
 import sys
 import time
 import mailbox
+import email
 
 def log_command(port=8825, host='127.0.0.1', chroot=False,
                 chdir=".", uid=False, gid=False, umask=False, pid="./run/log.pid",
@@ -423,3 +424,20 @@ def cleanse_command(input=None, output=None):
 
     print "TOTAL ERRORS:", error_count
 
+
+def blast_command(input=None, host='127.0.0.1', port=8823, debug=0):
+    """
+    Given a maildir, this command will go through each email
+    and blast it at your server.  It does nothing to the message, so
+    it will be real messages hitting your server, not cleansed ones.
+    """
+    inbox = mailbox.Maildir(input)
+    relay = server.Relay(host, port=port, debug=debug)
+
+    for key in inbox.keys():
+        msgfile = inbox.get_file(key)
+        msg = email.message_from_file(msgfile)
+        relay.deliver(msg)
+
+
+
