@@ -13,6 +13,7 @@ APIs for doing attachments and such.
 
 import mimetypes
 from lamson import encoding
+import os
 
 
 class MailRequest(object):
@@ -121,14 +122,6 @@ class MailResponse(object):
         self.multipart = self.Body and self.Html
         self.attachments = []
 
-    def as_string(self):
-        """Legacy function that will go away."""
-        return str(self)
-
-    def as_message(self):
-        """Legacy function that will go away."""
-        return self.to_message()
-    
     def __contains__(self, key):
         return self.msg.__contains__(key)
 
@@ -141,18 +134,41 @@ class MailResponse(object):
     def __delitem__(self, name):
         del self.msg[name]
 
-    def attach(self, filename, content_type=None):
+    def attach(self, filename=None, content_type=None, data=None, disposition=None):
         """
-        Takes the given file, figures out the mime type and
-        required encoding, and then sets it up to be attached
-        when you call to_message.
+        Simplifies attaching files from disk or data as files.  To attach simple
+        text simple give data and a content_type.  To attach a file, give the
+        data/content_type/filename/disposition combination.
+
+        For convenience, if you don't give data and only a filename, then it
+        will read that file's contents when you call to_message() later.  If you 
+        give data and filename then it will assume you've filled data with what
+        the file's contents are and filename is just the name to use.
         """
+        assert filename or data, "You must give a filename or some data to attach."
+        assert data or os.path.exists(filename), "File doesn't exist, and no data given."
+
         self.multipart = True
 
-        if not content_type:
+        if filename and not content_type:
             content_type, encoding = mimetypes.guess_type(filename)
 
-        self.attachments.append((filename, content_type))
+        assert content_type, "No content type given, and couldn't guess from the filename: %r" % filename
+
+        self.attachments.append({'filename': filename,
+                                 'content_type': content_type,
+                                 'data': data,
+                                 'disposition': disposition})
+       
+    def clear(self):
+        """
+        Clears out the attachments so you can redo them.  Use this to keep the
+        headers for a series of different messages with different attachments.
+        """
+        del self.attachments[:]
+        del self.msg.parts[:]
+        self.multipart = False
+
 
     def update(self, message):
         """
@@ -168,9 +184,21 @@ class MailResponse(object):
         """
         return str(self.to_message())
 
-    def _encode_attachment(self, filename, content_type):
-        data = open(filename).read()
-        self.msg.attach_file(filename, data, content_type, 'attachment')
+    def _encode_attachment(self, filename=None, content_type=None, data=None,
+                           disposition=None):
+        """
+        Used internally to take the attachments mentioned in self.attachments
+        and do the actual encoding in a lazy way when you call to_message.
+        """
+        if filename:
+            if not data:
+                data = open(filename).read()
+
+            self.msg.attach_file(filename, data, content_type, disposition or 'attachment')
+        else:
+            self.msg.attach_text(data, content_type)
+
+        self.msg.content_encoding['Content-Type'] = ('multipart/mixed', {})
 
     def to_message(self):
         """
@@ -194,7 +222,7 @@ class MailResponse(object):
                 self.msg.attach_text(self.Html, 'text/html')
 
             for args in self.attachments:
-                self._encode_attachment(*args)
+                self._encode_attachment(**args)
 
         elif self.Body:
             self.msg.body = self.Body
