@@ -6,9 +6,7 @@ API for the 90% case of "put mail in, get mail out" queues.
 """
 
 import mailbox
-import os
 from lamson import mail
-from functools import wraps
 
 class Queue(object):
     """
@@ -17,9 +15,9 @@ class Queue(object):
     most robust, but could implement others later.
     """
 
-    def __init__(self, dir):
-        self.dir = dir
-        self.mbox = mailbox.Maildir(dir)
+    def __init__(self, queue_dir):
+        self.dir = queue_dir
+        self.mbox = mailbox.Maildir(queue_dir)
 
     def push(self, message):
         """
@@ -51,10 +49,10 @@ class Queue(object):
         Get the specific message referenced by the key.  The message is NOT
         removed from the queue.
         """
-        file = self.mbox.get_file(key)
-        if not file: 
+        msg_file = self.mbox.get_file(key)
+        if not msg_file: 
             return None
-        return mail.MailRequest(self.dir, None, None, file.read())
+        return mail.MailRequest(self.dir, None, None, msg_file.read())
 
 
     def remove(self, key):
