@@ -9,7 +9,7 @@ import asyncore
 import threading
 import logging
 from sqlalchemy import create_engine
-from sqlalchemy.orm import mapper, sessionmaker, relation
+from sqlalchemy.orm import sessionmaker
 from lamson import queue, mail, routing
 import time
 import traceback
@@ -169,12 +169,12 @@ class QueueReceiver(object):
         logging.debug("Sleeping for %d seconds..." % self.sleep)
 
         while True:
-            q = queue.Queue(self.queue_dir)
-            key, msg = q.pop()
+            inq = queue.Queue(self.queue_dir)
+            key, msg = inq.pop()
             while key:
                 logging.debug("Pulled message with key: %r off", key)
                 self.process_message(msg)
-                key, msg = q.pop()
+                key, msg = inq.pop()
 
             if one_shot: 
                 return
@@ -186,7 +186,7 @@ class QueueReceiver(object):
         Exactly the same as SMTPReceiver.process_message but just designed for the queue's
         quirks.
         """
-        Data=str(msg)
+        Data = str(msg)
         Peer = self.queue_dir # this is probably harmless but I should check it
         From = msg['from']
         To = [msg['to']]
