@@ -25,7 +25,7 @@ Router.defaults(**settings.router_defaults)
 Router.load(settings.handlers + settings.queue_handlers)
 Router.RELOAD=False
 
-view.LOADER = jinja2.Environment(loader=jinja2.PackageLoader('lamson_tests', '.'))
+view.LOADER = jinja2.Environment(loader=jinja2.PackageLoader('lamson_tests', 'templates'))
 
 # if you have pyenchant and enchant installed then the template tests will do
 # spell checking for you, but you need to tell pyenchant where to find itself
