@@ -75,9 +75,34 @@ def test_mail_response_attachments():
                                  Subject="Test message",
                                  From="sender@zedshaw.com",
                                  Body="Test from test_mail_response_attachments.")
-    sample.attach("./README")
+    readme_data = open("./README").read()
+
+    assert_raises(AssertionError, sample.attach, filename="./README", disposition="inline")
+
+    sample.attach(filename="./README", content_type="text/plain", disposition="inline")
+    assert len(sample.attachments) == 1
+    assert sample.multipart
+
+    msg = sample.to_message()
+    assert_equal(len(msg.get_payload()), 2)
+
+    sample.clear()
+    assert len(sample.attachments) == 0
+    assert not sample.multipart
+
+    sample.attach(data=readme_data, filename="./README", content_type="text/plain")
+
+    msg = sample.to_message()
+    assert_equal(len(msg.get_payload()), 2)
+    sample.clear()
+
+    sample.attach(data=readme_data, content_type="text/plain")
+    msg = sample.to_message()
+    assert_equal(len(msg.get_payload()), 2)
+
     return sample
 
+
 def test_mail_request_attachments():
     sample = test_mail_response_attachments()
     data = str(sample)
@@ -120,7 +145,7 @@ def test_mail_response_mailing_list_headers():
     msg["References"] = 'Message-Id-838845854'
     msg["Precedence"] = 'list'
 
-    data = msg.as_string()
+    data = str(msg)
 
     req = mail.MailRequest('localhost', 'zedshaw@zedshaw.com', list_addr, data)
 
@@ -141,3 +166,6 @@ def test_mail_response_ignore_case_headers():
     assert_equal(msg['From'], msg['fRom'])
     assert_equal(msg['From'], msg['from'])
     assert_equal(msg['from'], msg['fRom'])
+
+
+
