@@ -20,7 +20,7 @@ def teardown():
 def test_Filter():
     sf = spam.Filter(ham_db, 'tests/.hammierc')
     ham_msg = test_mail_request().to_message()
-    spam_msg = test_mail_response_plain_text().as_message()
+    spam_msg = test_mail_response_plain_text().to_message()
     sf.newdb()
 
     sf.train_ham(ham_msg)
