@@ -42,6 +42,6 @@ def test_spelling():
     if 'PYENCHANT_LIBRARY_PATH' not in os.environ:
         os.environ['PYENCHANT_LIBRARY_PATH'] = '/opt/local/lib/libenchant.dylib'
 
-    template = "tests/lamson_tests/template.txt"
+    template = "tests/lamson_tests/templates/template.txt"
     contents = open(template).read()
     assert spelling(template, contents) 
